Enum spirv_headers::ImageChannelOrder
[−]
[src]
#[repr(u32)]pub enum ImageChannelOrder { R, A, RG, RA, RGB, RGBA, BGRA, ARGB, Intensity, Luminance, Rx, RGx, RGBx, Depth, DepthStencil, sRGB, sRGBx, sRGBA, sBGRA, ABGR, }
SPIR-V operand kind: ImageChannelOrder
Variants
RARGRARGBRGBABGRAARGBIntensityLuminanceRxRGxRGBxDepthDepthStencilsRGBsRGBxsRGBAsBGRAABGRTrait Implementations
impl Clone for ImageChannelOrder[src]
fn clone(&self) -> ImageChannelOrder
Returns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0
Performs copy-assignment from source. Read more
impl Copy for ImageChannelOrder[src]
impl Debug for ImageChannelOrder[src]
impl PartialEq for ImageChannelOrder[src]
fn eq(&self, __arg_0: &ImageChannelOrder) -> bool
This method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, other: &Rhs) -> bool1.0.0
This method tests for !=.
impl Eq for ImageChannelOrder[src]
impl FromPrimitive for ImageChannelOrder[src]
fn from_i64(n: i64) -> Option<Self>
Convert an i64 to return an optional value of this type. If the type cannot be represented by this value, the None is returned. Read more
fn from_u64(n: u64) -> Option<Self>
Convert an u64 to return an optional value of this type. If the type cannot be represented by this value, the None is returned. Read more
fn from_isize(n: isize) -> Option<Self>
Convert an isize to return an optional value of this type. If the value cannot be represented by this value, the None is returned. Read more
fn from_i8(n: i8) -> Option<Self>
Convert an i8 to return an optional value of this type. If the type cannot be represented by this value, the None is returned. Read more
fn from_i16(n: i16) -> Option<Self>
Convert an i16 to return an optional value of this type. If the type cannot be represented by this value, the None is returned. Read more
fn from_i32(n: i32) -> Option<Self>
Convert an i32 to return an optional value of this type. If the type cannot be represented by this value, the None is returned. Read more
fn from_usize(n: usize) -> Option<Self>
Convert a usize to return an optional value of this type. If the type cannot be represented by this value, the None is returned. Read more
fn from_u8(n: u8) -> Option<Self>
Convert an u8 to return an optional value of this type. If the type cannot be represented by this value, the None is returned. Read more
fn from_u16(n: u16) -> Option<Self>
Convert an u16 to return an optional value of this type. If the type cannot be represented by this value, the None is returned. Read more
fn from_u32(n: u32) -> Option<Self>
Convert an u32 to return an optional value of this type. If the type cannot be represented by this value, the None is returned. Read more
fn from_f32(n: f32) -> Option<Self>
Convert a f32 to return an optional value of this type. If the type cannot be represented by this value, the None is returned. Read more
fn from_f64(n: f64) -> Option<Self>
Convert a f64 to return an optional value of this type. If the type cannot be represented by this value, the None is returned. Read more